@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-10 14:40:50
-# @Last Modified time: 2021-03-08 15:10:02
+# @Last Modified time: 2021-03-10 17:40:28
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
@@ -96,10 +96,12 @@ class MysqlDB(DBCommon, DBFileExec):
         sqlcompile = SqlMysqlCompile(tablename)
         sql_for_dump = sqlcompile.dumpsql(columns, dumpfile, condition=condition)
         rows, action, result = self.execute(sql_for_dump, verbose=verbose)
+        mysqllogger.info(f"【{action}】{tablename} dumpdata {rows} rows succeed, outfile: {dumpfile} !")
         return rows, action, result
 
     def loaddata(self, tablename, columns, loadfile, verbose=0):
         sqlcompile = SqlMysqlCompile(tablename)
         sql_for_load = sqlcompile.loadsql(columns, loadfile)
         rows, action, result = self.execute(sql_for_load, verbose=verbose)
+        mysqllogger.info(f"【{action}】{tablename} loaddata {rows} rows succeed, loadfile: {loadfile} !")
         return rows, action, result
